@@ -546,8 +546,12 @@ bonobo_ui_component_new_default (void)
 	char              *name;
 	BonoboUIComponent *component;
 	static int idx = 0;
+	static int pid = 0;
 
-	name = g_strdup_printf ("%d-%d", getpid (), idx++);
+	if (!pid)
+		pid = getpid ();
+
+	name = g_strdup_printf ("%d-%d", pid, idx++);
 
 	component = bonobo_ui_component_new (name);
 	
@@ -638,6 +642,7 @@ impl_xml_set (BonoboUIComponent  *component,
 
 	name = component->priv->name ? component->priv->name : "";
 
+/*	fprintf (stderr, "setNode ( '%s', '%s', '%s' )", path, xml, name); */
 	Bonobo_UIContainer_setNode (container, path, xml,
 				    name, real_ev);
 
