@@ -320,7 +320,7 @@ bonobo_ui_util_xml_get_pixbuf (GtkWidget    *widget,
 
 	else if ((pixbuf = g_hash_table_lookup (pixbuf_cache, key))) {
 		g_free (key);
-		g_object_ref (G_OBJECT (pixbuf));
+		g_object_ref (pixbuf);
 		return pixbuf;
 	}
 
@@ -360,7 +360,7 @@ bonobo_ui_util_xml_get_pixbuf (GtkWidget    *widget,
 		g_warning ("Unknown icon_pixbuf type '%s'", type);
 
 	if (pixbuf) {
-		g_object_ref (G_OBJECT (pixbuf));
+		g_object_ref (pixbuf);
 		g_hash_table_insert (pixbuf_cache, key, pixbuf);
 	} else
 		g_free (key);
@@ -429,7 +429,7 @@ bonobo_ui_util_xml_get_icon_widget (BonoboUINode *node, GtkIconSize icon_size)
 		icon_pixbuf = bonobo_ui_util_xml_to_pixbuf (text);
 		if (icon_pixbuf) {
 			image = gtk_image_new_from_pixbuf (icon_pixbuf);
-			gdk_pixbuf_unref (icon_pixbuf);
+			g_object_unref (icon_pixbuf);
 		}
 	} else
 		g_warning ("Unknown icon_pixbuf type '%s'", type);
@@ -612,7 +612,7 @@ bonobo_ui_util_build_help_menu (BonoboUIComponent *listener,
 		bonobo_ui_component_add_verb (listener, id,
 					      bonobo_help_display_cb, entry);
 
-		gtk_signal_connect (GTK_OBJECT (listener), "destroy",
+		g_signal_connect (GTK_OBJECT (listener), "destroy",
 				    (GtkSignalFunc) free_help_menu_entry, 
 				    entry);
 		g_free (id);
